@@ -85,7 +85,7 @@ class MultiXgboostModel(BaseModel):
                 cols.append(col)
 
             df2.dropna(axis=0, how='any', inplace=True)
-            x = df2[df2.columns[1:-len(cols)]].values
+            x = df2[df2.columns[1:-1 - len(cols)]].values
             y = df2[cols].values
             return x, y
         else:
